MbrPartitionType

Enum MbrPartitionType 

pub enum MbrPartitionType {
Show 17 variants Empty, Fat12, Fat16, Extended, Fat16Lba, Ntfs, Fat32, Fat32Lba, ExtendedLba, Iso9660, LinuxSwap, LinuxNative, LinuxLvm, LinuxRaid, ProtectiveMbr, EfiSystemPartition, Unknown(u8),
}
A simplified enum for common MBR partition types.

For a complete list of partition types, see MbrPartitionTypeFull.

Variants



Empty

An unused partition-table entry.



Fat12

A FAT12 partition.



Fat16

A FAT16 partition.



Extended

A legacy extended partition.



Fat16Lba

A FAT16 partition addressed through LBA extensions.



Ntfs

An NTFS or other installable-file-system partition.



Fat32

A FAT32 partition.



Fat32Lba

A FAT32 partition addressed through LBA extensions.



ExtendedLba

An extended partition addressed through LBA extensions.



Iso9660

An ISO9660 filesystem or hidden NTFS partition.



LinuxSwap

A Linux swap partition.



LinuxNative

A native Linux filesystem partition.



LinuxLvm

A Linux Logical Volume Manager partition.



LinuxRaid

A Linux software RAID partition.



ProtectiveMbr

A GPT protective MBR entry.



EfiSystemPartition

An EFI System Partition.



Unknown(u8)

A partition type not represented by a named variant.

Implementations

Source

impl MbrPartitionType

pub const fn from_u8(value: u8) -> Self

Create a MbrPartitionType from a raw byte value.

pub const fn to_u8(&self) -> u8

Convert this partition type to its raw byte value.

pub const fn is_empty(&self) -> bool

Returns whether this partition type represents an empty/unused partition.

pub const fn is_protective(&self) -> bool

Returns whether this is a protective MBR (used for GPT disks).