#[repr(C, packed(1))]pub struct MasterBootRecord {
pub bootstrap: [u8; 446],
pub partition_table: MbrPartitionTable,
pub signature: [u8; 2],
}Expand description
The complete Master Boot Record structure (512 bytes).
@hadris-spec MBR:layout @hadris-compliance unknown @hadris-tests roundtrip::mbr_write_read_roundtrip
Fields
bootstrap: [u8; 446]Bootstrap code area (446 bytes).
partition_table: MbrPartitionTablePartition table (64 bytes - 4 entries of 16 bytes each).
signature: [u8; 2]Boot signature (must be 0x55, 0xAA).
Implementations
Sourceimpl MasterBootRecord
impl MasterBootRecord
Sourcepub const fn new(partition_table: MbrPartitionTable) -> Self
pub const fn new(partition_table: MbrPartitionTable) -> Self
Creates a new MBR with the given partition table.
Sourcepub const fn protective(disk_sectors: u64) -> Self
pub const fn protective(disk_sectors: u64) -> Self
Creates a protective MBR for GPT disks.
Sourcepub const fn has_valid_signature(&self) -> bool
pub const fn has_valid_signature(&self) -> bool
Returns whether this MBR has a valid boot signature.
Sourcepub fn get_partition_table(&self) -> MbrPartitionTable
pub fn get_partition_table(&self) -> MbrPartitionTable
Returns a copy of the partition table.
This method exists because the struct is packed and direct field access would create a misaligned reference.
Sourcepub fn set_partition_table(&mut self, table: MbrPartitionTable)
pub fn set_partition_table(&mut self, table: MbrPartitionTable)
Sets the partition table.
This method exists because the struct is packed and direct field access would create a misaligned reference.
Sourcepub fn with_partition_table<F>(&mut self, f: F)where
F: FnOnce(&mut MbrPartitionTable),
pub fn with_partition_table<F>(&mut self, f: F)where
F: FnOnce(&mut MbrPartitionTable),
Modifies the partition table using a closure.
This is a convenience method that gets the partition table, allows modification via a closure, and sets it back.