PartitionInfo

Struct PartitionInfo 

pub struct PartitionInfo {
    pub index: usize,
    pub start_lba: u64,
    pub end_lba: u64,
    pub size_sectors: u64,
    pub bootable: bool,
    pub partition_type: PartitionType,
}
Information about a partition, independent of the underlying scheme.

Fields

index: usize

Partition index (0-based).

start_lba: u64

Starting LBA.

end_lba: u64

Ending LBA (inclusive).

size_sectors: u64

Size in sectors.

bootable: bool

Whether the partition is bootable/active.

partition_type: PartitionType

Partition type (MBR type code or GPT type GUID).

Implementations

Source

impl PartitionInfo

pub const fn size_bytes(&self) -> u64

Returns the size in bytes (assuming 512-byte sectors).

Saturates to u64::MAX on corrupt inputs whose sector count is not representable in bytes.

pub const fn size_bytes_with_sector_size(&self, sector_size: u32) -> u64

Returns the size in bytes for a given sector size.

Saturates to u64::MAX on corrupt inputs whose sector count is not representable in bytes.