pub enum MbrPartitionType {
Show 17 variants
Empty,
Fat12,
Fat16,
Extended,
Fat16Lba,
Ntfs,
Fat32,
Fat32Lba,
ExtendedLba,
Iso9660,
LinuxSwap,
LinuxNative,
LinuxLvm,
LinuxRaid,
ProtectiveMbr,
EfiSystemPartition,
Unknown(u8),
}Expand description
A simplified enum for common MBR partition types.
For a complete list of partition types, see MbrPartitionTypeFull.
Variants
Empty
An unused partition-table entry.
Fat12
A FAT12 partition.
Fat16
A FAT16 partition.
Extended
A legacy extended partition.
Fat16Lba
A FAT16 partition addressed through LBA extensions.
Ntfs
An NTFS or other installable-file-system partition.
Fat32
A FAT32 partition.
Fat32Lba
A FAT32 partition addressed through LBA extensions.
ExtendedLba
An extended partition addressed through LBA extensions.
Iso9660
An ISO9660 filesystem or hidden NTFS partition.
LinuxSwap
A Linux swap partition.
LinuxNative
A native Linux filesystem partition.
LinuxLvm
A Linux Logical Volume Manager partition.
LinuxRaid
A Linux software RAID partition.
ProtectiveMbr
A GPT protective MBR entry.
EfiSystemPartition
An EFI System Partition.
Unknown(u8)
A partition type not represented by a named variant.
Implementations
Sourceimpl MbrPartitionType
impl MbrPartitionType