#[repr(transparent)]pub struct MbrPartitionTable {
pub partitions: [MbrPartition; 4],
}Expand description
The MBR partition table (4 primary partition entries).
Fields
partitions: [MbrPartition; 4]The four primary partition entries.
Implementations
Sourceimpl MbrPartitionTable
impl MbrPartitionTable
Sourcepub const fn protective(disk_sectors: u64) -> Self
pub const fn protective(disk_sectors: u64) -> Self
Creates a protective MBR partition table for GPT disks.
This creates a single partition entry covering the entire disk, with type 0xEE (GPT Protective).
Sourcepub fn is_valid(&self) -> bool
pub fn is_valid(&self) -> bool
Returns whether this appears to be a valid MBR partition table.
Checks that boot indicators are valid (0x00 or 0x80).
Sourcepub fn is_protective(&self) -> bool
pub fn is_protective(&self) -> bool
Returns whether this is a protective MBR (indicating a GPT disk).
Sourcepub fn iter(&self) -> impl Iterator<Item = &MbrPartition>
pub fn iter(&self) -> impl Iterator<Item = &MbrPartition>
Returns an iterator over non-empty partitions.
Sourcepub fn iter_mut(&mut self) -> impl Iterator<Item = &mut MbrPartition>
pub fn iter_mut(&mut self) -> impl Iterator<Item = &mut MbrPartition>
Returns a mutable iterator over all partition slots.